@@ -48,7 +48,7 @@ ExportManager::ExportManager(QObject *parent) :
     mTempFile(QUrl()),
     mTempDir(nullptr)
 {
-    connect(this, &ExportManager::imageSaved, [this](const QUrl savedAt) {
+    connect(this, &ExportManager::imageSaved, [this](const QUrl &savedAt) {
         SpectacleConfig::instance()->setLastSaveFile(savedAt);
     });
 }
@@ -157,9 +157,14 @@ QString ExportManager::truncatedFilename(QString const &filename)
 }
 
 QString ExportManager::makeAutosaveFilename()
+{
+    return formatFilename(SpectacleConfig::instance()->autoSaveFilenameFormat());
+}
+
+QString ExportManager::formatFilename(const QString &nameTemplate)
 {
     const QDateTime timestamp = mPixmapTimestamp;
-    QString baseName = SpectacleConfig::instance()->autoSaveFilenameFormat();
+    QString baseName = nameTemplate;
     const QString baseDir = defaultSaveLocation();
     QString title;
 
@@ -186,10 +191,10 @@ QString ExportManager::makeAutosaveFilename()
                              
     // check if basename includes %[N]d token for sequential file numbering
     QRegularExpression paddingRE;
-    paddingRE.setPattern(QLatin1String("%(\\d*)d"));
+    paddingRE.setPattern(QStringLiteral("%(\\d*)d"));
     QRegularExpressionMatch paddingMatch;
                              
-    if (result.indexOf(paddingRE, 0, &paddingMatch) > -1) {
+    while (result.indexOf(paddingRE, 0, &paddingMatch) > -1) {
         int highestFileNumber = 0;
 
         // determine padding value
@@ -198,7 +203,7 @@ QString ExportManager::makeAutosaveFilename()
             paddedLength = paddingMatch.captured(1).toInt();
         }
 
-        // seach save directory for files
+        // search save directory for files
         QDir dir(baseDir);
         const QStringList fileNames = dir.entryList(QDir::Files, QDir::Name);
         
@@ -206,7 +211,7 @@ QString ExportManager::makeAutosaveFilename()
         if (fileNames.length() > 0) { 
             QString resultCopy = result;
             QRegularExpression fileNumberRE;
-            const QString replacement = QString::fromLatin1("(\\d{").append(QString::number(paddedLength)).append(QString::fromLatin1(",})"));
+            const QString replacement = QStringLiteral("(\\d{").append(QString::number(paddedLength)).append(QLatin1String(",})"));
             const QString fullNameMatch = QStringLiteral("^").append(resultCopy.replace(paddingMatch.captured(),replacement)).append(QStringLiteral("\\..*$"));
             fileNumberRE.setPattern(fullNameMatch);
 
@@ -280,6 +285,7 @@ QString ExportManager::makeSaveMimetype(const QUrl &url)
 bool ExportManager::writeImage(QIODevice *device, const QByteArray &format)
 {
     QImageWriter imageWriter(device, format);
+    imageWriter.setQuality(SpectacleConfig::instance()->compressionQuality());
     if (!(imageWriter.canWrite())) {
         emit errorMessage(i18n("QImageWriter cannot write image: %1", imageWriter.errorString()));
         return false;
@@ -294,7 +300,7 @@ bool ExportManager::localSave(const QUrl &url, const QString &mimetype)
     const QUrl dirPath(url.adjusted(QUrl::RemoveFilename));
     const QDir dir(dirPath.path());
 
-    if (!dir.mkpath(QLatin1String("."))) {
+    if (!dir.mkpath(QStringLiteral("."))) {
         emit errorMessage(xi18nc("@info",
                                  "Cannot save screenshot because creating "
                                  "the directory failed:<nl/><filename>%1</filename>",
@@ -512,3 +518,36 @@ void ExportManager::doPrint(QPrinter *printer)
     delete printer;
     return;
 }
+
+const QMap<QString, const char*> ExportManager::filenamePlaceholders {
+    {QStringLiteral("%Y"), I18N_NOOP2(
+            "A placeholder in the user configurable filename will replaced by the specified value",
+            "Year (4 digit)")},
+    {QStringLiteral("%y"), I18N_NOOP2(
+            "A placeholder in the user configurable filename will replaced by the specified value",
+            "Year (2 digit)")},
+    {QStringLiteral("%M"), I18N_NOOP2(
+            "A placeholder in the user configurable filename will replaced by the specified value",
+            "Month")},
+    {QStringLiteral("%D"), I18N_NOOP2(
+            "A placeholder in the user configurable filename will replaced by the specified value",
+            "Day")},
+    {QStringLiteral("%H"), I18N_NOOP2(
+            "A placeholder in the user configurable filename will replaced by the specified value",
+            "Hour")},
+    {QStringLiteral("%m"), I18N_NOOP2(
+            "A placeholder in the user configurable filename will replaced by the specified value",
+            "Minute")},
+    {QStringLiteral("%S"), I18N_NOOP2(
+            "A placeholder in the user configurable filename will replaced by the specified value",
+            "Second")},
+    {QStringLiteral("%T"), I18N_NOOP2(
+            "A placeholder in the user configurable filename will replaced by the specified value",
+            "Window Title")},
+    {QStringLiteral("%d"), I18N_NOOP2(
+            "A placeholder in the user configurable filename will replaced by the specified value",
+            "Sequential numbering")},
+    {QStringLiteral("%Nd"), I18N_NOOP2(
+            "A placeholder in the user configurable filename will replaced by the specified value",
+            "Sequential numbering, padded out to N digits")},
+};
