@@ -20,6 +20,7 @@
 #include "SaveOptionsPage.h"
 
 #include "SpectacleConfig.h"
+#include "ExportManager.h"
 
 #include <KIOWidgets/KUrlRequester>
 #include <KLocalizedString>
@@ -53,9 +54,40 @@ SaveOptionsPage::SaveOptionsPage(QWidget *parent) :
 
     mainLayout->addItem(new QSpacerItem(0, 18, QSizePolicy::Fixed, QSizePolicy::Fixed));
 
+    // Compression quality slider and current value display
+    QHBoxLayout *sliderHorizLayout = new QHBoxLayout();
+    QVBoxLayout *sliderVertLayout = new QVBoxLayout();
 
-    // filename chooser and instructional text
-    QVBoxLayout *saveNameLayout = new QVBoxLayout;
+    // Current value
+    QLabel *qualityValue = new QLabel();
+    qualityValue->setNum(SpectacleConfig::instance()->compressionQuality());
+    qualityValue->setMinimumWidth(qualityValue->fontInfo().pointSize()*3);
+
+    // Slider
+    mQualitySlider = new QSlider(Qt::Horizontal);
+    mQualitySlider->setRange(0, 100);
+    mQualitySlider->setTickInterval(5);
+    mQualitySlider->setSliderPosition(SpectacleConfig::instance()->compressionQuality());
+    mQualitySlider->setTickPosition(QSlider::TicksBelow);
+    mQualitySlider->setTracking(true);
+    connect(mQualitySlider, &QSlider::valueChanged, [=](int value) {
+        qualityValue->setNum(value);
+        markDirty();
+    });
+
+    sliderHorizLayout->addWidget(mQualitySlider);
+    sliderHorizLayout->addWidget(qualityValue);
+
+    sliderVertLayout->addLayout(sliderHorizLayout);
+
+    QLabel *qualitySliderDescription = new QLabel();
+    qualitySliderDescription->setText(i18n("Choose the image quality when saving with lossy image formats like JPEG"));
+
+    sliderVertLayout->addWidget(qualitySliderDescription);
+
+    mainLayout->addRow(i18n("Compression Quality:"), sliderVertLayout);
+
+    mainLayout->addItem(new QSpacerItem(0, 18, QSizePolicy::Fixed, QSizePolicy::Fixed));
 
     // filename chooser text field
     QHBoxLayout *saveFieldLayout = new QHBoxLayout;
@@ -73,6 +105,7 @@ SaveOptionsPage::SaveOptionsPage(QWidget *parent) :
             }
         }
     });
+    connect(mSaveNameFormat, &QLineEdit::textChanged,this, &SaveOptionsPage::updateFilenamePreview);
     mSaveNameFormat->setPlaceholderText(QStringLiteral("%d"));
     saveFieldLayout->addWidget(mSaveNameFormat);
 
@@ -85,41 +118,33 @@ SaveOptionsPage::SaveOptionsPage(QWidget *parent) :
         return items;
     }());
     connect(mSaveImageFormat, &QComboBox::currentTextChanged, this, &SaveOptionsPage::markDirty);
+    connect(mSaveImageFormat, &QComboBox::currentTextChanged, this, &SaveOptionsPage::updateFilenamePreview);
     saveFieldLayout->addWidget(mSaveImageFormat);
-    saveNameLayout->addLayout(saveFieldLayout);
+    mainLayout->addRow(i18n("Filename:"), saveFieldLayout);
 
+    mPreviewLabel = new QLabel(this);
+    mainLayout->addRow(i18nc("Preview of the user configured filename", "Preview:"), mPreviewLabel);
     // now the save filename format layout
-    const QString helpText = i18nc("%1 is the default filename of a screenshot",
-        "<p>You can use the following placeholders in the filename, which will be replaced "
-        "with actual text when the file is saved:</p>"
-
-        "<blockquote>"
-            "<b>%Y</b>: Year (4 digit)<br />"
-            "<b>%y</b>: Year (2 digit)<br />"
-            "<b>%M</b>: Month<br />"
-            "<b>%D</b>: Day<br />"
-            "<b>%H</b>: Hour<br />"
-            "<b>%m</b>: Minute<br />"
-            "<b>%S</b>: Second<br />"
-            "<b>%T</b>: Window title<br />"
-            "<b>%d</b>: Sequential numbering<br />"
-            "<b>%Nd</b>: Sequential numbering, padded out to N digits"
-        "</blockquote>"
-
-        "<p>To save to a sub-folder, use slashes, e.g.:</p>"
-
-        "<blockquote>"
-            "<b>%Y</b>/<b>%M</b>/%1"
-        "</blockquote>",
-        SpectacleConfig::instance()->defaultFilename() + SpectacleConfig::instance()->defaultTimestampTemplate()
+    QString helpText = i18n(
+        "You can use the following placeholders in the filename, which will be replaced "
+        "with actual text when the file is saved:<blockquote>"
     );
-
+    for (auto option = ExportManager::filenamePlaceholders.cbegin();
+         option != ExportManager::filenamePlaceholders.cend(); ++option) {
+        helpText += QStringLiteral("<a href=%1>%1</a>: %2<br>").arg(
+                option.key(),
+                i18nc("A placeholder in the user configurable filename will replaced by the specified value", option.value()));
+    }
+    helpText += QStringLiteral("<a href='/'>/</a>: ") + i18n("To save to a sub-folder");
+    helpText += QStringLiteral("</blockquote>");
     QLabel *fmtHelpText = new QLabel(helpText, this);
     fmtHelpText->setWordWrap(true);
     fmtHelpText->setTextFormat(Qt::RichText);
     fmtHelpText->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::MinimumExpanding);
-    saveNameLayout->addWidget(fmtHelpText);
-    mainLayout->addRow(i18n("Filename:"), saveNameLayout);
+    connect(fmtHelpText, &QLabel::linkActivated, [this](const QString& placeholder) {
+        mSaveNameFormat->insert(placeholder);
+    });
+    mainLayout->addWidget(fmtHelpText);
 
     // read in the data
     resetChanges();
@@ -142,6 +167,7 @@ void SaveOptionsPage::saveChanges()
     cfgManager->setAutoSaveFilenameFormat(mSaveNameFormat->text());
     cfgManager->setSaveImageFormat(mSaveImageFormat->currentText().toLower());
     cfgManager->setCopySaveLocationToClipboard(mCopyPathToClipboard->checkState() == Qt::Checked);
+    cfgManager->setCompressionQuality(mQualitySlider->value());
 
     // done
 
@@ -159,6 +185,7 @@ void SaveOptionsPage::resetChanges()
     mSaveNameFormat->setText(cfgManager->autoSaveFilenameFormat());
     mUrlRequester->setUrl(QUrl::fromUserInput(cfgManager->defaultSaveLocation()));
     mCopyPathToClipboard->setChecked(cfgManager->copySaveLocationToClipboard());
+    mQualitySlider->setSliderPosition(cfgManager->compressionQuality());
 
     // read in the save image format and calculate its index
 
@@ -173,3 +200,23 @@ void SaveOptionsPage::resetChanges()
 
     mChangesMade = false;
 }
+
+void SaveOptionsPage::updateFilenamePreview()
+{
+    ExportManager *exportManager = ExportManager::instance();
+    exportManager->setWindowTitle(QStringLiteral("Spectacle"));
+    using GrabMode = ImageGrabber::GrabMode;
+    GrabMode oldMode = exportManager->grabMode();
+    /* If the grabMode is not one of those below we need to change it to have the placeholder
+     * replaced by the window title */
+    bool changeAndRestoreGrabMode = !(oldMode == GrabMode::ActiveWindow
+        || oldMode == GrabMode::TransientWithParent || oldMode == GrabMode::WindowUnderCursor);
+    if (changeAndRestoreGrabMode) {
+       exportManager->setGrabMode(GrabMode::ActiveWindow);
+    }
+    const QString filename = exportManager->formatFilename(mSaveNameFormat->text());
+    mPreviewLabel->setText(xi18nc("@info", "<filename>%1.%2</filename>", filename, mSaveImageFormat->currentText().toLower()));
+    if (changeAndRestoreGrabMode) {
+        exportManager->setGrabMode(oldMode);
+    }
+}
