@@ -19,6 +19,8 @@
 
 #include "SpectacleConfig.h"
 
+#include <KWindowSystem>
+
 SpectacleConfig::SpectacleConfig(QObject *parent) :
     QObject(parent)
 {
@@ -176,6 +178,19 @@ void SpectacleConfig::setShowMagnifierChecked(bool enabled)
     mGuiConfig.sync();
 }
 
+// release mouse-button to capture
+
+bool SpectacleConfig::useReleaseToCapture() const
+{
+    return mGuiConfig.readEntry(QStringLiteral("useReleaseToCapture"), false);
+}
+
+void SpectacleConfig::setUseReleaseToCaptureChecked(bool enabled)
+{
+    mGuiConfig.writeEntry(QStringLiteral("useReleaseToCapture"), enabled);
+    mGuiConfig.sync();
+}
+
 // capture delay
 
 qreal SpectacleConfig::captureDelay() const
@@ -193,7 +208,7 @@ void SpectacleConfig::setCaptureDelay(qreal delay)
 
 int SpectacleConfig::captureMode() const
 {
-    return mGuiConfig.readEntry(QStringLiteral("captureModeIndex"), 0);
+    return std::max(0, mGuiConfig.readEntry(QStringLiteral("captureModeIndex"), 0));
 }
 
 void SpectacleConfig::setCaptureMode(int index)
@@ -206,7 +221,7 @@ void SpectacleConfig::setCaptureMode(int index)
 
 bool SpectacleConfig::rememberLastRectangularRegion() const
 {
-    return mGuiConfig.readEntry(QStringLiteral("rememberLastRectangularRegion"), false);
+    return mGuiConfig.readEntry(QStringLiteral("rememberLastRectangularRegion"), true);
 }
 
 void SpectacleConfig::setRememberLastRectangularRegion(bool enabled)
@@ -215,6 +230,19 @@ void SpectacleConfig::setRememberLastRectangularRegion(bool enabled)
     mGuiConfig.sync();
 }
 
+bool SpectacleConfig::alwaysRememberRegion() const
+{
+    // Default Value is for compatibility reasons as the old behavior was always to remember across restarts
+    bool useOldBehavior = mGuiConfig.readEntry(QStringLiteral("rememberLastRectangularRegion"), false);
+    return mGuiConfig.readEntry(QStringLiteral("alwaysRememberRegion"), useOldBehavior);
+}
+
+void SpectacleConfig::setAlwaysRememberRegion (bool enabled)
+{
+    mGuiConfig.writeEntry(QStringLiteral("alwaysRememberRegion"), enabled);
+    mGuiConfig.sync();
+}
+
 // use light region mask colour
 
 bool SpectacleConfig::useLightRegionMaskColour() const
@@ -228,6 +256,19 @@ void SpectacleConfig::setUseLightRegionMaskColour(bool enabled)
     mGuiConfig.sync();
 }
 
+// compression quality setting
+
+int SpectacleConfig::compressionQuality() const
+{
+    return mGuiConfig.readEntry(QStringLiteral("compressionQuality"), 90);
+}
+
+void SpectacleConfig::setCompressionQuality(int value)
+{
+    mGuiConfig.writeEntry(QStringLiteral("compressionQuality"), value);
+    mGuiConfig.sync();
+}
+
 // last used save mode
 
 SaveMode SpectacleConfig::lastUsedSaveMode() const
@@ -302,3 +343,21 @@ void SpectacleConfig::setSaveImageFormat(const QString &saveFmt)
     mGeneralConfig.writeEntry(QStringLiteral("default-save-image-format"), saveFmt);
     mGeneralConfig.sync();
 }
+
+SpectacleConfig::PrintKeyActionRunning SpectacleConfig::printKeyActionRunning() const
+{
+    mConfig->reparseConfiguration();
+    int newScreenshotAction = static_cast<int>(SpectacleConfig::PrintKeyActionRunning::TakeNewScreenshot);
+    int readValue = mGuiConfig.readEntry(QStringLiteral("printKeyActionRunning"), newScreenshotAction);
+    if ((KWindowSystem::isPlatformWayland() || qstrcmp(qgetenv("XDG_SESSION_TYPE"), "wayland") == 0 )
+        && readValue == SpectacleConfig::PrintKeyActionRunning::FocusWindow)  {
+        return SpectacleConfig::PrintKeyActionRunning::TakeNewScreenshot;
+    }
+    return static_cast<SpectacleConfig::PrintKeyActionRunning>(readValue);
+}
+
+void SpectacleConfig::setPrintKeyActionRunning (SpectacleConfig::PrintKeyActionRunning action)
+{
+    mGuiConfig.writeEntry(QStringLiteral("printKeyActionRunning"), static_cast<int>(action));
+    mGuiConfig.sync();
+}
